@@ -27,15 +27,15 @@ import datetime
 import socket
 import httplib
 import urllib
+import https
 
 import config
 import utils
 import remote
 import local
-import https
 
 
-VERSION = '0.2.8'
+VERSION = '0.3.0'
 
 
 def hook_setup(cmd):
@@ -115,17 +115,22 @@ def sign_request(api_key, method, request):
             }
     return headers
 
+_request = None
 def run_command(cmd, internal=False):
-    if internal is False and not os.path.exists(
-            os.path.join(config.CONFIG_DIR, 'dotcloud.key')):
+    global _request
+    if internal is False and not os.path.exists(config.CONFIG_KEY):
         run_command('get_key', True)
     data = None
     cfg = config.load_user_config()
     url = utils.parse_url(cfg.url)
-    if url['scheme'].lower() == 'https':
-        req = https.HTTPSConnection(url['host'], int(url['port'] or 443))
+    if _request:
+        req = _request
     else:
-        req = httplib.HTTPConnection(url['host'], int(url['port'] or 80))
+        if url['scheme'].lower() == 'https':
+            req = https.HTTPSConnection(url['host'], int(url['port'] or 443))
+        else:
+            req = httplib.HTTPConnection(url['host'], int(url['port'] or 80))
+        _request = req
     cmd = urllib.quote(json.dumps(cmd))
     query = '{0}run?{1}={2}'.format(url['path'], 'c' if internal is True else 'q', cmd)
     headers = sign_request(cfg.apikey, 'GET', query)
