@@ -24,7 +24,10 @@ import json
 from utils import die, info
 
 
-USERCONFIGFILE = os.path.expanduser(os.environ.get('DOTCLOUD_CONFIG_FILE', '~/.dotcloud.conf'))
+CONFIG_DIR = os.path.expanduser('~/.dotcloud')
+CONFIG_FILE = os.path.basename(os.environ.get('DOTCLOUD_CONFIG_FILE', 'dotcloud.conf'))
+CONFIG_PATH = os.path.join(CONFIG_DIR, CONFIG_FILE)
+CONFIG_KEY = os.path.join(CONFIG_DIR, 'dotcloud.key')
 
 
 class Config(dict):
@@ -38,7 +41,7 @@ class Config(dict):
     def __getattr__(self, key):
         return self[key]
 
-    def __setattr__(self, key, value): 
+    def __setattr__(self, key, value):
         self[key] = value
 
     def __delattr__(self, key):
@@ -55,23 +58,41 @@ def load(config_file):
     config = Config(config)
     return config
 
-
 def load_user_config():
-    if not os.path.exists(USERCONFIGFILE):
-        info('Warning: {0} does not exist.'.format(USERCONFIGFILE))
+    if not os.path.exists(CONFIG_PATH):
+        info('Warning: {0} does not exist.'.format(CONFIG_PATH))
         setup()
-    config = load(USERCONFIGFILE)
+    config = load(CONFIG_PATH)
     if 'url' not in config or 'apikey' not in config:
-        die("Configuration file not valid. Please run 'dotcloud setup' to create it.")
+        die('Configuration file not valid. Please run "dotcloud setup" to create it.')
     return config
 
+def move_old_config():
+    #FIXME: This function will be removed at the next release.
+    old_file = os.path.join(os.path.expanduser('~'), '.' + CONFIG_FILE)
+    if not os.path.exists(old_file):
+        return False
+    with open(old_file) as f:
+        data = f.read()
+    with open(CONFIG_PATH, 'w') as f:
+        if 'DOTCLOUD_CONFIG_FILE' not in os.environ:
+            data = data.replace('http://', 'https://')
+        f.write(data)
+        os.fchmod(f.fileno(), 0600)
+    info('Migrated from {0}'.format(old_file))
+    return True
+
 def setup():
     import re
-    conf = {}
-    conf['url'] = 'http://api.dotcloud.com/'
+    if not os.path.exists(CONFIG_DIR):
+        os.mkdir(CONFIG_DIR, 0700)
+    if move_old_config() is True:
+        return
+    conf = {'url': 'https://api.dotcloud.com/'}
     apikey = raw_input('Enter your api key (You can find it at http://www.dotcloud.com/account/settings): ')
     if not re.match('\w{20}:\w{40}', apikey):
         die('Not a valid api key.')
     conf['apikey'] = apikey
-    with open(USERCONFIGFILE, 'w') as f:
+    with open(CONFIG_PATH, 'w') as f:
         json.dump(conf, f, indent=4)
+        os.fchmod(f.fileno(), 0600)
